Reference — absorbing-centrality documentation

# Reference

## Computing the centrality of a set

`absorbing_centrality`(G, team[, query, P, ...]) | Compute the absorbing centrality of a team.
`absorbing_centrality_inversion`(G, team[, ...]) | Compute the absorbing centrality of a team using a fast inversion with SuperLU solver.

## Team-selection algorithms

`greedy_team`(G, k[, query, candidates, ...]) | Selects a team of nodes according to the greedy algorithm.

## Matrix-related functions

`compute_fundamental_matrix`(P[, fast, ...]) | Computes the fundamental matrix for an absorbing random walk.
`compute_transition_matrix`(G) | Builds the random transition matrix P.
`compute_personalized_transition_matrix`(G[, ...]) | Returns the transition matrix of the random walk with restarts.
`update_fundamental_matrix`(P, F, next, previous) | Applies Woodbury’s formula to update the fundamental matrix in order to avoid doing an inversion.

## Preprocessing the graph

`canonical_relabel_nodes`(G) | Relabels the nodes in the graph, such that the new names belong in the set [1,n].
`is_canonical`(G) | Tests if the graph has been canonicalized.
`add_supernode`(G[, query]) | Adds a supernode to the graph and connects it with directed edges to the query nodes.
`has_supernode`(G) | Checks if there exist a supernode in the graph.

## Exceptions

`CanonicalizationError`(message) | Exception related to the graph canonicalization procedure.